--- loncom/publisher/lonpubdir.pm 2011/10/26 17:31:40 1.133
+++ loncom/publisher/lonpubdir.pm 2014/01/21 18:23:35 1.149
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Construction Space Directory Lister
#
-# $Id: lonpubdir.pm,v 1.133 2011/10/26 17:31:40 www Exp $
+# $Id: lonpubdir.pm,v 1.149 2014/01/21 18:23:35 musolffc Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -33,7 +33,6 @@ use strict;
use Apache::File;
use File::Copy;
use Apache::Constants qw(:common :http :methods);
-use Apache::loncacc;
use Apache::loncommon();
use Apache::lonhtmlcommon();
use Apache::londiff();
@@ -47,12 +46,12 @@ sub handler {
my $r=shift;
- # Validate access to the construction space and get username@domain.
+ # Validate access to the construction space and get username:domain.
my $uname;
my $udom;
- ($uname,$udom)=&Apache::loncacc::constructaccess($r->uri);
+ ($uname,$udom)=&Apache::lonnet::constructaccess($r->uri);
unless (($uname) && ($udom)) {
return HTTP_NOT_ACCEPTABLE;
}
@@ -98,6 +97,7 @@ sub handler {
opendir(DIR,$fn);
my @files=sort {uc($a) cmp uc($b)} (readdir(DIR));
foreach my $filename (@files) {
+ next if ($filename eq '.DS_Store');
my ($cdev,$cino,$cmode,$cnlink,
$cuid,$cgid,$crdev,$csize,
$catime,$cmtime,$cctime,
@@ -144,20 +144,28 @@ sub startpage {
&Apache::lonhtmlcommon::clear_breadcrumbs();
&Apache::lonhtmlcommon::add_breadcrumb({
- 'text' => 'Construction Space',
- 'href' => &Apache::loncommon::authorspace(),
+ 'text' => 'Authoring Space',
+ 'href' => &Apache::loncommon::authorspace($formaction),
});
# breadcrumbs (and tools) will be created
# in start_page->bodytag->innerregister
$env{'request.noversionuri'}=$formaction;
- $r->print(&Apache::loncommon::start_page('Construction Space',undef));
+ $r->print(&Apache::loncommon::start_page('Authoring Space',undef));
+
+ my $londocroot = $Apache::lonnet::perlvar{'lonDocRoot'};
+ my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,"$londocroot/priv/$udom/$uname");
+ my $disk_quota = &Apache::loncommon::get_user_quota($uname,$udom,'author'); #expressed in Mb
+ $disk_quota = 1000 * $disk_quota; # convert from Mb to kb
$r->print(&Apache::loncommon::head_subbox(
- &Apache::loncommon::CSTR_pageheader(1)));
+ '
'
+ .&Apache::lonhtmlcommon::display_usage($current_disk_usage,$disk_quota)
+ .'
'
+ .&Apache::loncommon::CSTR_pageheader()));
my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
- my $doctitle = 'LON-CAPA '.&mt('Construction Space');
+ my $doctitle = 'LON-CAPA '.&mt('Authoring Space');
my $newname = &mt('New Name');
my $pubdirscript=(<
@@ -437,15 +445,19 @@ sub getSourceRightString {
}
#
# Put out a directory table row:
-# putdirectory(r, base, here, dirname, modtime)
-# r - Apache request object.
-# reqfile - File in request.
-# here - Where we are in directory tree.
-# dirname - Name of directory special file.
-# modtime - Encoded modification time.
-#
+# putdirectory(r, base, here, dirname, modtime, targetdir, bombs, numdir)
+# r - Apache request object.
+# reqfile - File in request.
+# here - Where we are in directory tree.
+# dirname - Name of directory special file.
+# modtime - Encoded modification time.
+# targetdir - Publication target directory.
+# bombs - Reference to hash of URLs with runtime error messages.
+# numdir - Reference to scalar used to track number of sub-directories
+# in directory (used in form name for each "actions" dropdown).
+#
sub putdirectory {
- my ($r, $reqfile, $here, $dirname, $modtime, $resdir, $bombs, $numdir) = @_;
+ my ($r, $reqfile, $here, $dirname, $modtime, $targetdir, $bombs, $numdir) = @_;
# construct the display filename: the directory name unless ..:
@@ -454,10 +466,13 @@ sub putdirectory {
my $disfilename = $dirname;
# Don't display directory itself, and there is no way up from root directory
unless ((($dirname eq '..') && ($reqfile=~/^\/[^\/]+\/[^\/]+$/)) || ($dirname eq '.')) {
- my $kaputt=0;
- foreach (keys %{$bombs}) {
- if ($_=~m:^\Q$resdir\E/\Q$disfilename\E/:) { $kaputt=1; last; }
- }
+ my $kaputt=0;
+ if (ref($bombs) eq 'HASH') {
+ foreach my $key (keys(%{$bombs})) {
+ my $currentdir = &Apache::lonnet::declutter("$targetdir/$disfilename");
+ if (($key) =~ m{^\Q$currentdir\E/}) { $kaputt=1; last; }
+ }
+ }
#
# Get the metadata from that directory's default.meta to display titles
#
@@ -493,7 +508,7 @@ sub putdirectory {
''.$actionitem.' | '.
''.
$disfilename.' | '.
- ''.($kaputt?&Apache::lonhtmlcommon::authorbombs($resdir.'/'.$disfilename.'/'):'').$Apache::lonpublisher::metadatafields{'title'});
+ ' | '.($kaputt?&Apache::lonhtmlcommon::authorbombs($targetdir.'/'.$disfilename.'/'):'').$Apache::lonpublisher::metadatafields{'title'});
if ($Apache::lonpublisher::metadatafields{'subject'} ne '') {
$r->print(' '.
$Apache::lonpublisher::metadatafields{'subject'}.
@@ -516,9 +531,9 @@ sub putresource {
my $pubstatus = 'unpublished';
my $status=&mt('Unpublished');
my $css_class='LC_browser_file';
- my $title=' ';
+ my $title='';
my $publish_button=&mt('Publish');
- my $cstr_dir = $r->dir_config('lonDocRoot').'/priv/'.$udom.'/'.$uname.'/'.$thisdisfn.'/';
+ my $cstr_dir = $r->dir_config('lonDocRoot').'/priv'.$thisdisfn;
my $linkfilename=&HTML::Entities::encode('/priv'.$thisdisfn.'/'.$filename,'<>&"');
if (-e $resdir.'/'.$filename) {
@@ -557,7 +572,7 @@ sub putresource {
$rights_status .=
$lt_SourceRight{&getSourceRightString($targetdir.'/'.$filename)};
- $title = ''.
&getTitleString($targetdir.'/'.$filename).'';
if ($same) {
@@ -578,30 +593,43 @@ sub putresource {
$status=&mt('Modified').
' '. $rights_status;
if (&Apache::loncommon::fileembstyle(($filename=~/\.(\w+)$/)) eq 'ssi') {
- $status.=' '.&mt('Diffs').'';
+ $status.=' '.
+ &Apache::loncommon::modal_link(
+ '/adm/diff?filename='.$linkfilename.'&versiontwo=priv',
+ &mt('Diffs'),600,500);
}
}
-
- $title.="\n".' '.
- ($$bombs{$targetdir.'/'.$filename}?'':&mt('Edit Metadata')).'';
-
if (!$meta_same) {
$title = &mt('Metadata Modified').' '.$title.
- ' '.&mt('Metadata Diffs').'';
- $title.="\n".' '.&mt('Retrieve Metadata').'';
+ ' '.
+ &Apache::loncommon::modal_link(
+ '/adm/diff?filename='.$linkfilename.'.meta'.'&versiontwo=priv',
+ &mt('Metadata Diffs'),600,500);
+ $title.="\n".' '.
+ &Apache::loncommon::modal_link(
+ '/adm/retrieve?filename='.$linkfilename.'.meta&inhibitmenu=yes&add_modal=yes',
+ &mt('Retrieve Metadata'),600,500);
}
- $status.="\n".' '.&mt('Retrieve').'';
- }
+ $status.="\n".' '.
+ &Apache::loncommon::modal_link(
+ '/adm/retrieve?filename='.$linkfilename.'&inhibitmenu=yes&add_modal=yes',&mt('Retrieve'),600,500);
+ }
+ # Allow editing metadata of published and unpublished resources
+ $title .= "\n".' ' if ($title);
+ $title .= ''.
+ ($$bombs{&Apache::lonnet::declutter($targetdir.'/'.$filename)}?
+ '':
+ &mt('Edit Metadata')).
+ '';
+
my $editlink='';
my $editlink2='';
if ($filename=~/\.(xml|html|htm|xhtml|xhtm|sty)$/) {
- $editlink=' ('.&mt('Edit').')';
+ $editlink=' ('.&mt('Edit').')';
}
- if ($filename=~/\.(problem|exam|quiz|assess|survey|form|library)$/) {
- $editlink=' ('.&mt('EditXML').')';
- $editlink2=' ('.&mt('Edit').')';
+ if ($filename=~/$LONCAPA::assess_re/) {
+ $editlink=' ('.&mt('EditXML').')';
+ $editlink2=' ('.&mt('Edit').')';
}
if ($filename=~/\.(problem|exam|quiz|assess|survey|form|library|xml|html|htm|xhtml|xhtm|sty)$/) {
$editlink.=' ('.&mt('Clean Up').')';
@@ -687,13 +715,13 @@ __END__
=head1 NAME
-Apache::lonpubdir - Construction space directory lister
+Apache::lonpubdir - Authoring space directory lister
=head1 SYNOPSIS
Invoked (for various locations) by /etc/httpd/conf/srm.conf:
-
+
PerlAccessHandler Apache::loncacc
SetHandler perl-script
PerlHandler Apache::lonpubdir
@@ -766,16 +794,20 @@ Output the header of the page. This inc
$str = getTitleString($fullname);
$fullname - Fully qualified filename to check.
-=item putdirectory(r, base, here, dirname, modtime)
+=item putdirectory($r, $base, $here, $dirname, $modtime, $targetdir, $bombs,
+ $numdir)
Put out a directory table row:
- putdirectory($r, $base, $here, $dirname, $modtime)
- $r - Apache request object.
- $reqfile - File in request.
- $here - Where we are in directory tree.
- $dirname - Name of directory special file.
- $modtime - Encoded modification time.
+ $r - Apache request object.
+ $reqfile - File in request.
+ $here - Where we are in directory tree.
+ $dirname - Name of directory special file.
+ $modtime - Encoded modification time.
+ targetdir - Publication target directory.
+ bombs - Reference to hash of URLs with runtime error messages.
+ numdir - Reference to scalar used to track number of sub-directories
+ in directory (used in form name for each "actions" dropdown).
=back
|
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
-# Construction Space Directory Lister
+# Authoring Space Directory Lister
#